@@ -1,5 +1,5 @@
-from mandawsdl.input import Input
-from mandawsdl.color import Color
+from mandaw.input import Input
+from mandaw.color import Color
 import sdl2, sdl2.ext
 
 class Mandaw:
@@ -73,7 +73,7 @@ class SoftwareRenderer(sdl2.ext.SoftwareSpriteRenderSystem):
         super().render(components)
 
 if __name__ == "__main__":
-    from mandawsdl import *
+    from mandaw import *
 
     mandaw = Mandaw(title = "Mandaw!", width = 800, height = 600, bg_color = Color(0, 0, 0))
 
